==> active_campaign_api_integration-1.1.0.tar.gz: active_campaign_api_integration/README.md <==
# Active Campaign API integration

This module integrates with the ActiveCampaign API and allows users to
map registration form fields to ActiveCampaign fields for automatic data
transfer.

For a full description of the module, visit the
[project page](https://www.drupal.org/project/active_campaign_api_integration).

Submit bug reports and feature suggestions, or track changes in the
[issue queue](https://www.drupal.org/project/issues/active_campaign_api_integration).


## Table of contents

- Requirements
- Installation
- Configuration
- Maintainers


## Requirements

This module requires api keys from [ActiveCampaign](https://www.activecampaign.com) site.


## Installation

Install as you would normally install a contributed Drupal module. For further
information, see
[Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).


## Configuration

1. Get your api keys from [ActiveCampaign](https://www.activecampaign.com) site.
2. Go to Administration » Configuration » Campaign Dashboard on your site and map your registration
    form fields with ActiveCampaign.
3. Make sure at least one mapping is enabled here _admin/config/active-campaign-map-user_ else no
data will be sent to ActiveCampaign on user creation.


## Maintainers

- Chance Nyasulu - [chancenyasulu](https://www.drupal.org/u/chancenyasulu)
- Neha Verma - [Neha-Verma](https://www.drupal.org/u/neha-verma)
- Shekhar Verma - [D-XPERT](https://www.drupal.org/u/d-xpert)
- Jasjeet Brar - [Jasjeet Kaur Brar](https://www.drupal.org/u/jasjeet-kaur-brar)

==> active_campaign_api_integration-2.0.0.tar.gz: active_campaign_api_integration/README.md <==
# Active Campaign API integration

This module integrates with the ActiveCampaign API and allows users to
map registration form fields to ActiveCampaign fields for automatic data
transfer.

For a full description of the module, visit the
[project page](https://www.drupal.org/project/active_campaign_api_integration).

Submit bug reports and feature suggestions, or track changes in the
[issue queue](https://www.drupal.org/project/issues/active_campaign_api_integration).


## Table of contents

- Requirements
- Installation
- Configuration
- Maintainers


## Requirements

This module requires api keys from [ActiveCampaign](https://www.activecampaign.com) site.


## Installation

Install as you would normally install a contributed Drupal module. For further
information, see
[Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).


## Configuration

1. Get your api keys from [ActiveCampaign](https://www.activecampaign.com) site.
2. Go to Administration » Configuration » Campaign Dashboard on your site and
   map your registration form fields with ActiveCampaign.
3. Make sure at least one mapping is enabled here
   _admin/config/active-campaign-map-user_ else no data will be sent to
   ActiveCampaign on user creation.


## Maintainers

- Chance Nyasulu - [chancenyasulu](https://www.drupal.org/u/chancenyasulu)
- Neha Verma - [Neha-Verma](https://www.drupal.org/u/neha-verma)
- Shekhar Verma - [D-XPERT](https://www.drupal.org/u/d-xpert)
- Jasjeet Brar - [Jasjeet Kaur Brar](https://www.drupal.org/u/jasjeet-kaur-brar)
